package Map::Metro::Plugin::Map::Brescia::Lines;

our $VERSION = '0.1101'; our $VERSION = '0.1000'; # VERSION

1;

__END__

=encoding utf-8

=head1 NAME

Map::Metro::Plugin::Map::Brescia::Lines - Detailed information about Map::Metro::Plugin::Map::Brescia

=head1 LINES

=head2 Line 1: Prealpino → Sant'Eufemia-Buffalora [L1]

    Prealpino
    Casazza
    Mompiano
    Europa
    Ospedale
    Marconi
    San Faustino
    Vittoria
    Stazione F.S.
    Brescia Due
    Lamarmora
    Volta
    Poliambulanza
    San Polo Parco
    San Polo Cimabue
    Sampolino
    Sant'Eufemia-Buffalora


=head1 SEE ALSO

L<Map::Metro::Plugin::Map::Brescia>

=cut

